"""
Info script
"""
__version__ = "2.5.1"
__homepage__ = "https://github.com/jackd248/db-sync-tool"
